import { FontObjectV2, FontObjectVariable, FontObjectV1 } from 'google-font-metadata';
export { APIIconStatic, APIIconVariable, APILicense, APIRegistry, APIVariable, APIv1, APIv2 } from 'google-font-metadata';

declare const create: () => Promise<void>;

interface CLIOptions {
    test?: boolean;
    force?: boolean;
    ttf?: boolean;
}
interface BuildOptions {
    dir: string;
    tmpDir: string;
    force: boolean;
    isVariable: boolean;
    noSubset?: boolean;
    isIcon?: boolean;
    version?: string;
    publishHash?: string;
    ttf?: boolean;
}
interface CSSGenerateItem {
    filename: string;
    css: string;
}
type CSSGenerate = CSSGenerateItem[];

interface VerifyProps {
    font?: string;
    ci?: boolean;
    cwd?: string;
}
declare const verify: ({ font, ci, cwd }: VerifyProps) => Promise<void>;

type GenerateIconStatic = Pick<FontObjectV2['id'], 'id' | 'family' | 'styles' | 'weights' | 'subsets' | 'variants'>;
type GenerateIconVariable = Pick<FontObjectVariable['id'], 'id' | 'family' | 'axes' | 'variants'>;
declare const generateIconStaticCSS: (metadata: GenerateIconStatic, makeFontFilePath: (id: string, subset: string, weight: string, style: string, extension: string) => string, tag?: string) => CSSGenerate;
declare const packagerIconsStatic: (id: string, opts: BuildOptions) => Promise<void>;
declare const generateIconVariableCSS: (metadata: GenerateIconVariable, makeFontFilePath: (id: string, subset: string, axesLower: string, style: string) => string, tag?: string) => CSSGenerate;
declare const packagerIconsVariable: (id: string, opts: BuildOptions) => Promise<void>;

type GenerateMetadataV1 = Pick<FontObjectV1['id'], 'id' | 'family' | 'styles' | 'weights' | 'subsets' | 'variants'>;
declare const generateV1CSS: (metadata: GenerateMetadataV1, makeFontFilePath: (id: string, subset: string, weight: string, style: string, extension: string) => string, tag?: string) => CSSGenerate;
declare const packagerV1: (id: string, opts: BuildOptions) => Promise<void>;

type GenerateMetadataV2$1 = Pick<FontObjectV2['id'], 'id' | 'family' | 'styles' | 'weights' | 'subsets' | 'variants' | 'unicodeRange'>;
declare const generateV2CSS: (metadata: GenerateMetadataV2$1, makeFontFilePath: (id: string, subset: string, weight: string, style: string, extension: string) => string, tag?: string) => CSSGenerate;
declare const packagerV2: (id: string, opts: BuildOptions) => Promise<void>;

type GenerateMetadataV2 = Pick<FontObjectV2['id'], 'id' | 'family' | 'unicodeRange' | 'weights'>;
type GenerateMetadataVariable = Pick<FontObjectVariable['id'], 'axes' | 'variants'>;
declare const generateVariableCSS: (metadata: GenerateMetadataV2, variableMeta: GenerateMetadataVariable, makeFontFilePath: (id: string, subset: string, axes: string, style: string) => string, tag?: string) => CSSGenerate;
declare const packagerVariable: (id: string, opts: BuildOptions) => Promise<void>;

declare const processGoogle: (opts: CLIOptions, fonts?: string[]) => Promise<void>;

export { create, generateIconStaticCSS, generateIconVariableCSS, generateV1CSS, generateV2CSS, generateVariableCSS, packagerIconsStatic, packagerIconsVariable, packagerV1, packagerV2, packagerVariable, processGoogle, verify };
